@@ -1,13 +1,13 @@
 var classFl__File__Browser =
 [
     [ "Fl_File_Browser", "classFl__File__Browser.html#a37cd337622c04b85947efa56421b4ed9", null ],
+    [ "errmsg", "classFl__File__Browser.html#a02a5867b9c79dd09847d3ea3e0cf8d61", null ],
+    [ "errmsg", "classFl__File__Browser.html#ad3b6f26d02386469e5e65fb17d8a7b9b", null ],
     [ "filetype", "classFl__File__Browser.html#ac62c921cd140c70d28ec0559b3b9f235", null ],
     [ "filetype", "classFl__File__Browser.html#af29b1735a961d308a27baea8db5a6bfb", null ],
-    [ "filter", "classFl__File__Browser.html#a9c1e9439555fd0274f328b3e84db4e9c", null ],
+    [ "filter", "classFl__File__Browser.html#a3665fcfe73a48b48805222f81ab41a10", null ],
     [ "filter", "classFl__File__Browser.html#ad7e7db3e10220cc85f11c702eaf17733", null ],
     [ "iconsize", "classFl__File__Browser.html#a81f8b827c293a7eae3156b4f6b6815a6", null ],
     [ "iconsize", "classFl__File__Browser.html#a41275ecf3707f7b642732cf5727a1d82", null ],
-    [ "load", "classFl__File__Browser.html#a5999b749fe1d6102362e573cdb6ae32d", null ],
-    [ "textsize", "classFl__File__Browser.html#a08ac5de63c992eb381c00ce7298a32a6", null ],
-    [ "textsize", "classFl__File__Browser.html#a4958486381d0947c89a2f34e01eb3439", null ]
+    [ "load", "classFl__File__Browser.html#a5999b749fe1d6102362e573cdb6ae32d", null ]
 ];
\ No newline at end of file
